@@ -1,16 +1,33 @@
 """The `JOptional` class provides a java like Optional class"""
+
+# Copyright 2022 the original author or authors (i.e.: St4rG00se for Dev4py).
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      https://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from __future__ import annotations
 
+from functools import partial
 from typing import Generic, Optional, Final, Any, cast, Awaitable
 
 from dev4py import utils
 from dev4py.utils import objects
 from dev4py.utils.awaitables import is_awaitable
+from dev4py.utils.objects import to_self, to_none
 from dev4py.utils.types import T, Supplier, Function, R, Consumer, Runnable, Predicate, SyncOrAsync
 
 
 class JOptional(Generic[T]):
-    """A class inspired from the java.util.Optional class"""
+    """A class inspired by the java.util.Optional class"""
 
     __EMPTY: JOptional[Any]
     __CREATE_KEY: Final[object] = object()
@@ -96,9 +113,9 @@ class JOptional(Generic[T]):
         Returns:
             value: The value, if present, otherwise other
         """
-        return self.or_else_get(lambda: other)
+        return self.or_else_get(cast(Supplier[Optional[T]], partial(to_self, obj=other)))
 
-    def or_else_get(self, supplier: Supplier[Optional[T]] = lambda: None) -> Optional[T]:
+    def or_else_get(self, supplier: Supplier[Optional[T]] = to_none) -> Optional[T]:
         """
         If a value is present, returns the value, otherwise returns the result produced by the supplying function
 
@@ -114,8 +131,17 @@ class JOptional(Generic[T]):
         objects.require_non_none(supplier)
         return self._value if self.is_present() else supplier()
 
+    @staticmethod  # pragma: no mutate
+    def __or_else_raise_supplier_lambda() -> Exception:
+        """
+        private static method to replace or_else_raise lambda supplier by a function
+        Note: lambda are not used in order to be compatible with multiprocessing (lambda are not serializable)
+        """
+        # lambda: cast(Exception, ValueError(JOptional.__NO_VALUE_ERROR_MSG))
+        return cast(Exception, ValueError(JOptional.__NO_VALUE_ERROR_MSG))
+
     def or_else_raise(
-            self, supplier: Supplier[Exception] = lambda: cast(Exception, ValueError(JOptional.__NO_VALUE_ERROR_MSG))
+            self, supplier: Supplier[Exception] = __or_else_raise_supplier_lambda
     ) -> T:
         """
         If a value is present, returns the value, otherwise raises an exception produced by the exception supplying
@@ -156,6 +182,15 @@ class JOptional(Generic[T]):
         objects.require_non_none(supplier)
         return self if self.is_present() else objects.require_non_none(supplier())
 
+    @staticmethod  # pragma: no mutate
+    def __map_lambda(v: T, mapper: Function[T, Optional[R]]) -> JOptional[R]:
+        """
+        private static method to replace inner map lambda supplier by a function
+        Note: lambda are not used in order to be compatible with multiprocessing (lambda are not serializable)
+        """
+        # lambda v: JOptional.of_noneable(mapper(v))
+        return JOptional.of_noneable(mapper(v))
+
     def map(self, mapper: Function[T, Optional[R]]) -> JOptional[R]:
         """
         If a value is present, returns a JOptional describing (as if by of_noneable) the result of applying the given
@@ -174,7 +209,7 @@ class JOptional(Generic[T]):
             TypeError: If the mapping function is None
         """
         objects.require_non_none(mapper)
-        return self.flat_map(lambda v: JOptional.of_noneable(mapper(v)))
+        return self.flat_map(partial(JOptional.__map_lambda, mapper=mapper))
 
     def flat_map(self, mapper: Function[T, JOptional[R]]) -> JOptional[R]:
         """
